Where possible the HTTP `PUT` method should be globally disabled. This
can typically be done with a simple configuration change on the
server. The steps to disable the `PUT` method will differ depending on
the type of server being used (IIS, Apache, etc.).

For cases where
the `PUT` method is required to meet application functionality, such
as REST style web services, strict limitations should be implemented
to ensure that only secure (SSL/TLS enabled) and authorised clients
are permitted to use the `PUT` method.

Additionally, the server's
file system permissions should also enforce strict limitations.